# SupportRequestAcknowledgementSpec

Configuration containing properties associated with a support request that is allowed to provide support to the organisation. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**supporting_user_id** | **str** | ID of the supporting user, used to confirm that they can provide support to the support request  | 
**org_id** | **str** | Org ID of the supporting user | 
**support_request_id** | **str** | ID of a support request, used as a binder to the support request | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


